@@ -1020,14 +1020,7 @@ impl From<glium::program::ProgramChooserCreationError> for RendererCreationError
     }
 }
 
-impl std::error::Error for RendererCreationError {
-    fn description(&self) -> &str {
-        match *self {
-            RendererCreationError::Texture(ref e) => std::error::Error::description(e),
-            RendererCreationError::Program(ref e) => std::error::Error::description(e),
-        }
-    }
-}
+impl std::error::Error for RendererCreationError {}
 
 impl std::fmt::Display for RendererCreationError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
@@ -1050,14 +1043,7 @@ impl From<glium::DrawError> for DrawError {
     }
 }
 
-impl std::error::Error for DrawError {
-    fn description(&self) -> &str {
-        match *self {
-            DrawError::Buffer(ref e) => std::error::Error::description(e),
-            DrawError::Draw(ref e) => std::error::Error::description(e),
-        }
-    }
-}
+impl std::error::Error for DrawError {}
 
 impl std::fmt::Display for DrawError {
     fn fmt(&self, f: &mut std::fmt::Formatter) -> Result<(), std::fmt::Error> {
